Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1682)

Unified Diff: webrtc/modules/utility/include/helpers_ios.h

Issue 1746023002: Modifies SDK and iOS detection for helper method that needs iOS 9+ (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Improvements proposed by tkchin@ Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/utility/include/helpers_ios.h
diff --git a/webrtc/modules/utility/include/helpers_ios.h b/webrtc/modules/utility/include/helpers_ios.h
index d3f788fec30e9f1fc98032a340558fa298dc25c6..1b692f18c18b56ae907007d5e330627dfb2d091d 100644
--- a/webrtc/modules/utility/include/helpers_ios.h
+++ b/webrtc/modules/utility/include/helpers_ios.h
@@ -37,11 +37,12 @@ std::string GetAudioSessionCategory();
// Returns the current name of the operating system.
std::string GetSystemName();
-// Returns the current version of the operating system.
-std::string GetSystemVersion();
+// Returns the current version of the operating system as a string.
+std::string GetSystemVersionAsString();
-// Returns the version of the operating system as a floating point value.
-float GetSystemVersionAsFloat();
+// Returns the version of the operating system in double representation.
+// Uses a cached value of the system version.
+double GetSystemVersion();
// Returns the device type.
// Examples: ”iPhone” and ”iPod touch”.

Powered by Google App Engine
This is Rietveld 408576698